{***************************************************************************}
{ TDBFinder freeware components by Deborah Pate                             }
{ Version 1.81, May 1999                                                    }
{                                                                           }
{ Utility functions for TDBFinder controls, data-aware controls for         }
{ finding records in 32-bit Delphi.                                         }
{                                                                           }
{***************************************************************************}
unit DBFFuncs;

interface
{$D-}
uses
  Sysutils, Classes, Controls;

type
  EDBFinderError = class(Exception);
  TFilterMode = (fmApplyFilter, fmIgnoreFilter, fmRemoveFilter);

  TDBFinderInfo = record
    Datafield: string;
    GroupIndex: cardinal;
    IsAFinder: boolean;
    TabOrder: integer;
    Text: string;
  end;

procedure ClearDBFinder(Control: TControl);
function GetDBFinderInfo(const Control: TControl): TDBFinderInfo;


{$IFOPT D+}
  {$IFDEF VER90}
  procedure Assert(Cond: boolean; Message: string);
  {$ENDIF}
{$ENDIF}

{$IFDEF VER90}
  const
{$ELSE}
  resourcestring
{$ENDIF}
  SNoDatafield = 'No datafield selected';
  STableOpenFailed = 'Could not open dataset %s';
  SUnknownFinder = 'Unknown DBFinder type';
  SCannotGroupDisplayField = 'Cannot set GroupIndex > 0 while the ' + #13+#10
                           + 'DisplayField property is not empty.' + #13+#10 + #13+#10
                           + 'Delete DisplayField value?';
  SWarning = 'Warning';


implementation

uses
   DB, DBFCombo, DBFEdit;

procedure ClearDBFinder(Control: TControl);
{ Clears a control's text property, or sets its itemindex to -1 }
begin
   if Control.ClassType = TDBFinderEdit then begin
        TDBFinderEdit(Control).Text := '';
   end
   else if Control.ClassType = TDBFinderCombo then begin
        TDBFinderCombo(Control).ItemIndex := -1;
   end
   else raise EDBFinderError.Create(SUnknownFinder);
end;

function GetDBFinderInfo(const Control: TControl): TDBFinderInfo;
{ Returns the information needed for a DBFinder to perform a group search }
begin
   Result.IsAFinder := False;
   if Control.ClassType = TDBFinderEdit then begin
      Result.Datafield := TDBFinderEdit(Control).Datafield;
      Result.GroupIndex := TDBFinderEdit(Control).GroupIndex;
      Result.IsAFinder := True;
      Result.TabOrder := TDBFinderEdit(Control).TabOrder;
      Result.Text := TDBFinderEdit(Control).Text;
   end
   else
   if Control.ClassType = TDBFinderCombo then begin
      Result.Datafield := TDBFinderCombo(Control).Datafield;
      Result.GroupIndex := TDBFinderCombo(Control).GroupIndex;
      Result.IsAFinder := True;
      Result.TabOrder := TDBFinderCombo(Control).TabOrder;
      Result.Text := TDBFinderCombo(Control).Text;
   end;
end;

{$IFOPT D+}
  {$IFDEF VER90}
  procedure Assert(Cond: boolean; Message: string);
  begin
    if not Cond then begin
      raise EDBFinderError.Create(Message);
    end;
  end;
  {$ENDIF}
{$ENDIF}


end.
